@@ -248,8 +248,8 @@ InitTimers () {
     iAllSetsProgressBarNo=0
     if [[ $iActiveTimersCount -eq 0 ]]; then
         # If active timers count = 0, error message & clear run count
-        yad  --window-icon="/usr/share/icons/papirus-antix/48x48/apps/xfce4-timer.png" --title "mutli-timer error" "$GEOMETRY" --text \
-            "At least one non-zero timer required." --image=dialog-error \
+        yad  --window-icon="/usr/share/icons/papirus-antix/48x48/apps/xfce4-timer.png" --title $"mutli-timer error" "$GEOMETRY" --text \
+            $"At least one non-zero timer required." --image=dialog-error \
             --on-top --borders=20 --button=gtk-close:0
         iAllSetsRemainingCount=0 # Set orderly exit via sibling function(s)
         iProgressBarCount=0
